Account Activation
==================
App for activating a users account.

Flow
====
1. Navigate to the account activation page
    1. If the token is expired the user is redirected to a token expired page.
    2. If the token is valid and non-expired, activate the account and redirect the user to a success page.